@@ -28,6 +28,7 @@
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "base/base.h"
+#include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 
 namespace mozc {
@@ -38,6 +39,7 @@ int main(int argc, char **argv) {
   // TODO(yukawa, team): Implement b/2805528 so that you can specify any option
   // given by gunit.
   InitGoogle(argv[0], &argc, &argv, false);
+  mozc::InitTestFlags();
   testing::InitGoogleTest(&argc, argv);
 
   // Without this flag, ::RaiseException makes the job stuck.
